==> jc-1.4.0.tar.gz: javax/swing/text/BadLocationException.h <==
// public class javax.swing.text.BadLocationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class a6f0748cb2d57926 javax_swing_text_BadLocationException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_swing_text_BadLocationException_H_
#define _JC_javax_swing_text_BadLocationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_BadLocationException$sub_refs	_jc_javax_swing_text_BadLocationException$sub_refs;
typedef struct _jc_javax_swing_text_BadLocationException$sub_nonrefs	_jc_javax_swing_text_BadLocationException$sub_nonrefs;
typedef struct _jc_javax_swing_text_BadLocationException$refs	_jc_javax_swing_text_BadLocationException$refs;
typedef struct _jc_javax_swing_text_BadLocationException$nonrefs	_jc_javax_swing_text_BadLocationException$nonrefs;
typedef struct _jc_javax_swing_text_BadLocationException$object	_jc_javax_swing_text_BadLocationException$object;

typedef struct _jc_javax_swing_text_BadLocationException$fields_struct	_jc_javax_swing_text_BadLocationException$fields_struct;
typedef const struct _jc_javax_swing_text_BadLocationException$vmethods	_jc_javax_swing_text_BadLocationException$vmethods;
typedef const struct _jc_javax_swing_text_BadLocationException$vtable	_jc_javax_swing_text_BadLocationException$vtable;
typedef const struct _jc_javax_swing_text_BadLocationException$vtype	_jc_javax_swing_text_BadLocationException$vtype;

// Class fields structure
struct _jc_javax_swing_text_BadLocationException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_BadLocationException$fields_struct _jc_javax_swing_text_BadLocationException$class_fields;

// Constructors
extern void _jc_javax_swing_text_BadLocationException$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_javax_swing_text_BadLocationException$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern jint _jc_javax_swing_text_BadLocationException$method$offsetRequested$1de8969f73664a42(_jc_env *, struct _jc_javax_swing_text_BadLocationException$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_BadLocationException$method_info$offsetRequested$1de8969f73664a42;

// Virtual methods structure
struct _jc_javax_swing_text_BadLocationException$vmethods {
	jint	(*offsetRequested$1de8969f73664a42)(_jc_env *, struct _jc_javax_swing_text_BadLocationException$object *);
};

// Vtable
struct _jc_javax_swing_text_BadLocationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_swing_text_BadLocationException$vmethods	javax_swing_text_BadLocationException;
};

// Vtype
struct _jc_javax_swing_text_BadLocationException$vtype {
	_jc_type			type;
	_jc_javax_swing_text_BadLocationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_BadLocationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_BadLocationException$refs {
    _jc_javax_swing_text_BadLocationException$sub_refs	javax_swing_text_BadLocationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_BadLocationException$sub_nonrefs {
	jint	offset;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_BadLocationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_swing_text_BadLocationException$sub_nonrefs	javax_swing_text_BadLocationException;
};

// Object instance structure
struct _jc_javax_swing_text_BadLocationException$object {
	_jc_javax_swing_text_BadLocationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_BadLocationException$vtype	*vtype;
	_jc_javax_swing_text_BadLocationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_BadLocationException$vtype _jc_javax_swing_text_BadLocationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_BadLocationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_BadLocationException$class_object;

#endif	/* _JC_javax_swing_text_BadLocationException_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/BadLocationException.h <==
// public class javax.swing.text.BadLocationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class a6f0748cb2d57926 javax_swing_text_BadLocationException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_swing_text_BadLocationException_H_
#define _JC_javax_swing_text_BadLocationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_BadLocationException$sub_refs	_jc_javax_swing_text_BadLocationException$sub_refs;
typedef struct _jc_javax_swing_text_BadLocationException$sub_nonrefs	_jc_javax_swing_text_BadLocationException$sub_nonrefs;
typedef struct _jc_javax_swing_text_BadLocationException$refs	_jc_javax_swing_text_BadLocationException$refs;
typedef struct _jc_javax_swing_text_BadLocationException$nonrefs	_jc_javax_swing_text_BadLocationException$nonrefs;
typedef struct _jc_javax_swing_text_BadLocationException$object	_jc_javax_swing_text_BadLocationException$object;

typedef struct _jc_javax_swing_text_BadLocationException$fields_struct	_jc_javax_swing_text_BadLocationException$fields_struct;
typedef const struct _jc_javax_swing_text_BadLocationException$vmethods	_jc_javax_swing_text_BadLocationException$vmethods;
typedef const struct _jc_javax_swing_text_BadLocationException$vtable	_jc_javax_swing_text_BadLocationException$vtable;
typedef const struct _jc_javax_swing_text_BadLocationException$vtype	_jc_javax_swing_text_BadLocationException$vtype;

// Class fields structure
struct _jc_javax_swing_text_BadLocationException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_BadLocationException$fields_struct _jc_javax_swing_text_BadLocationException$class_fields;

// Constructors
extern void _jc_javax_swing_text_BadLocationException$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_javax_swing_text_BadLocationException$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_text_BadLocationException$method$offsetRequested$1de8969f73664a42(_jc_env *, struct _jc_javax_swing_text_BadLocationException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_BadLocationException$method_info$offsetRequested$1de8969f73664a42;

// Virtual methods structure
struct _jc_javax_swing_text_BadLocationException$vmethods {
	jint	(*offsetRequested$1de8969f73664a42)(_jc_env *, struct _jc_javax_swing_text_BadLocationException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_BadLocationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_swing_text_BadLocationException$vmethods	javax_swing_text_BadLocationException;
};

// Vtype
struct _jc_javax_swing_text_BadLocationException$vtype {
	_jc_type			type;
	_jc_javax_swing_text_BadLocationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_BadLocationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_BadLocationException$refs {
    _jc_javax_swing_text_BadLocationException$sub_refs	javax_swing_text_BadLocationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_BadLocationException$sub_nonrefs {
	jint	offset;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_BadLocationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_swing_text_BadLocationException$sub_nonrefs	javax_swing_text_BadLocationException;
};

// Object instance structure
struct _jc_javax_swing_text_BadLocationException$object {
	_jc_javax_swing_text_BadLocationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_BadLocationException$vtype	*vtype;
	_jc_javax_swing_text_BadLocationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_BadLocationException$vtype _jc_javax_swing_text_BadLocationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_BadLocationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_BadLocationException$class_object;

#endif	/* _JC_javax_swing_text_BadLocationException_H_ */
